@@ -16,6 +16,7 @@ CONSERVEMEM = (("-c","--conserve-memory"),{'action':'store_true','dest':'conserv
 CONFIG = [
     ("auto",{'help':"start HTTP server for given COUNTRY (default: Europe)",'args':[SHOW,URL,CONSERVEMEM,NOBROWSER,HOST,PORT,PREFIX,RHOST,RPORT,RPREFIX,OSM,COUNTRIES]}),
     ("nx",{'help':"start HTTP server for given GRAPH and rendered HTML file",'args':[SHOW,URL,NOBROWSER,HOST,PORT,PREFIX,RHOST,RPORT,RPREFIX,GRAPH,HTML]}),
+    ("npz",{'help':"start HTTP server for given GRAPH and rendered HTML file",'args':[SHOW,URL,NOBROWSER,HOST,PORT,PREFIX,RHOST,RPORT,RPREFIX,GRAPH,HTML]})
 ]
 
 def serve_auto(countries,host="localhost",port=5000,prefix="",osm=False,url=None,show=False,no_browser=False,r_host="localhost",r_port=5000,r_prefix="",conserve_mem=False):
@@ -29,28 +30,39 @@ def serve_auto(countries,host="localhost",port=5000,prefix="",osm=False,url=None
         extract_osm_all(countries=countries,conserve_mem=conserve_mem)
     else:
         countries, url = common(countries=countries,url=url,show=show,osm=osm,join=True)
-        download_graph(suffix="nx",countries=countries,url=url,show=show,join=True)
+        download_graph(suffix="npz",countries=countries,url=url,show=show,join=True)
     if len(countries) > 1 :
         merge_all(countries)
     if len(countries) == 1:
-        graph_file = "graph."+countries[0]+".nx"
+        graph_file = "graph."+countries[0]+(".nx" if osm else ".npz")
     html_file = graph_file[:-2]+"html"
-    serve_nx(graph_file,html_file,host=host,port=port,prefix=prefix,url=url,show=show,no_browser=no_browser,r_host=r_host,r_port=r_port,r_prefix=r_prefix)
+    if osm:
+        serve_nx(graph_file,html_file,host=host,port=port,prefix=prefix,url=url,show=show,no_browser=no_browser,r_host=r_host,r_port=r_port,r_prefix=r_prefix)
+    else:
+        serve_npz(graph_file,html_file,host=host,port=port,prefix=prefix,url=url,show=show,no_browser=no_browser,r_host=r_host,r_port=r_port,r_prefix=r_prefix)
         
     
 def serve_nx(graph_file,html_file,host="localhost",port=5000,prefix="",url=None,show=False,no_browser=False,r_host="localhost",r_port=5000,r_prefix=""):
+    from limic.render import render_nx
+    from limic.route import astar_nx
+    g,nodes = render_nx(graph_file,html_file,host=r_host,port=r_port,prefix=r_prefix)
+    serve(g,nodes,astar_nx,html_file,host,port,prefix,url,show,no_browser,r_host,r_port,r_prefix)
+
+def serve_npz(graph_file,html_file,host="localhost",port=5000,prefix="",url=None,show=False,no_browser=False,r_host="localhost",r_port=5000,r_prefix=""):
+    from limic.render import render_npz
+    from limic.route import astar_npz
+    g,nodes = render_npz(graph_file,html_file,host=r_host,port=r_port,prefix=r_prefix)
+    serve(g,nodes,astar_npz,html_file,host,port,prefix,url,show,no_browser,r_host,r_port,r_prefix)
+
+def serve(g,nodes,astar,html_file,host="localhost",port=5000,prefix="",url=None,show=False,no_browser=False,r_host="localhost",r_port=5000,r_prefix=""):
     from flask import Flask, jsonify, request
     from limic.util import load_pickled, start, end, status
-    from limic.route import astar_nx
-    from limic.render import render_nx
     from threading import Thread
     from time import sleep
     from webbrowser import open as wopen
     from scipy.spatial import cKDTree as KDTree
     from pyproj import CRS, Transformer
-    g = render_nx(graph_file,html_file,host=r_host,port=r_port,prefix=r_prefix)
     start("Initializing KD-Tree")
-    nodes = list(g.nodes())
     crs_4326 = CRS("WGS84")
     crs_proj = CRS("EPSG:28992")
     transformer = Transformer.from_crs(crs_4326, crs_proj)
@@ -82,11 +94,13 @@ def serve_nx(graph_file,html_file,host="localhost",port=5000,prefix="",url=None,
         target_lat = float(request.args.get('target[lat]'))
         target_lng = float(request.args.get('target[lng]'))
         start("Routing",source_lat,source_lng,target_lat,target_lng)
-        source = nodes[tree.query(transformer.transform(source_lat,source_lng))[1]]
+        source_index = tree.query(transformer.transform(source_lat,source_lng))[1]
+        source = nodes[source_index]
         end('')
-        target = nodes[tree.query(transformer.transform(target_lat,target_lng))[1]]
+        target_index = tree.query(transformer.transform(target_lat,target_lng))[1]
+        target = nodes[target_index]
         end('')
-        path = astar_nx(g,source,target)
+        path = astar(g,(source,source_index),(target,target_index))
         end('')
         if path[1][-1][0] == float('inf'):
             path[1][-1] = (path[1][-1][1],)+path[1][-1][1:]
